@@ -214,7 +214,7 @@ data_preprocess <- function(data) { # , varnames) {
                    } else if (is.list(x)) {
                      x <- data_list2array(x) # list to array
                    } else if (is.logical(x)) {
-                     x <- as.integer(x)
+                     storage.mode(x) <- "integer"
                    }
 
                    ## Now we stop whenever we have NA in the data
@@ -1587,10 +1587,8 @@ get_time_from_csv <- function(tlines) {
   t <- rep(NA, 2)
   names(t) <- c("warmup", "sample")
   if (length(tlines) < 2) return(t)
-  warmupt <- gsub(".*#\\s*Elapsed.*:\\s*", "", tlines[1])
-  warmupt <- gsub("\\s*seconds.*$", "", warmupt)
-  samplet <- gsub(".*#\\s*", "", tlines[2])
-  samplet <- gsub("\\s*seconds.*$", "", samplet)
+  warmupt <- gsub("[^0-9.]", "", tlines[1])
+  samplet <- gsub("[^0-9.]", "", tlines[2])
   t[1] <- as.double(warmupt)
   t[2] <- as.double(samplet)
   t
@@ -1713,3 +1711,4 @@ test_221 <- function(cppcode) {
   grepl("Code generated by Stan version 2.2", cppcode, fixed = TRUE) ||
   grepl("Code generated by Stan version 3", cppcode, fixed = TRUE)  
 }
+
