@@ -19,8 +19,6 @@ rstan_load_time <- as.POSIXct("1970-01-01 00:00.00 UTC")
 RNG <- 0
 OUT <- 0
 
-tbbmalloc_proxyDllInfo <- NULL
-
 .onLoad <- function(libname, pkgname) {
   assignInMyNamespace("rstan_load_time", value = Sys.time())
   set_rstan_ggplot_defaults()
@@ -28,13 +26,6 @@ tbbmalloc_proxyDllInfo <- NULL
   assignInMyNamespace("OUT", value = get_stream())
   Rcpp::loadModule("class_model_base", what = TRUE)
   Rcpp::loadModule("class_stan_fit", what = TRUE)
-  ## the tbbmalloc_proxy is not loaded by RcppParallel which is linked
-  ## in by default on macOS; unloading only works under R >= 4.0 so that
-  ## this is only done for R >= 4.0
-  if(R.version$major >= 4 && Sys.info()["sysname"] == "Darwin") {
-      tbbmalloc_proxy  <- system.file("lib/libtbbmalloc_proxy.dylib", package="RcppParallel", mustWork=FALSE)
-      tbbmalloc_proxyDllInfo <<- dyn.load(tbbmalloc_proxy, local = FALSE, now = TRUE)
-  }
 }
 
 .onAttach <- function(...) {
@@ -54,10 +45,4 @@ tbbmalloc_proxyDllInfo <- NULL
 .onUnload <- function(libpath) {
    # unload the package library
    library.dynam.unload("rstan", libpath)
-
-   # unload tbbmalloc_proxy if we loaded it
-   if (!is.null(tbbmalloc_proxyDllInfo)) {
-       dyn.unload(tbbmalloc_proxyDllInfo[["path"]])
-       tbbmalloc_proxyDllInfo <<- NULL
-   }
 }
